pub struct FocusTrackerConfig {
pub poll_interval: Duration,
pub icon: IconConfig,
pub icon_cache_capacity: usize,
pub linux_ignore_rules: IgnoreRules,
pub macos_ignore_rules: IgnoreRules,
pub windows_ignore_rules: IgnoreRules,
}Fields
poll_interval: Durationicon: IconConfigicon_cache_capacity: usizelinux_ignore_rules: IgnoreRulesIgnore rules applied when running on Linux.
Consulted only by the Linux tracker; ignored on other platforms.
See IgnoreRule for the matcher semantics.
macos_ignore_rules: IgnoreRulesIgnore rules applied when running on macOS.
Consulted only by the macOS tracker; ignored on other platforms.
See IgnoreRule for the matcher semantics.
windows_ignore_rules: IgnoreRulesIgnore rules applied when running on Windows.
Consulted only by the Windows tracker; ignored on other platforms.
See IgnoreRule for the matcher semantics.
Implementations
Sourceimpl FocusTrackerConfig
impl FocusTrackerConfig
Sourcepub fn ignore_rules_for_current_platform(&self) -> &IgnoreRules
pub fn ignore_rules_for_current_platform(&self) -> &IgnoreRules
Returns the ignore rules that apply to the current build target.
Sourceimpl FocusTrackerConfig
impl FocusTrackerConfig
Sourcepub fn builder() -> FocusTrackerConfigBuilder
pub fn builder() -> FocusTrackerConfigBuilder
Creates a new focus tracker configuration using the builder pattern.
Example
use focus_tracker_core::{FocusTrackerConfig, IconConfig, IgnoreRule, WindowTitleMatch};
use std::time::Duration;
let config = FocusTrackerConfig::builder()
.poll_interval(Duration::from_millis(50))
.unwrap()
.icon(IconConfig::builder().size(64).unwrap().build())
.windows_ignore_rules([
IgnoreRule::builder()
.process_name("whatever")
.window_title(WindowTitleMatch::Missing)
.build(),
])
.build();Trait Implementations
Sourceimpl Clone for FocusTrackerConfig
impl Clone for FocusTrackerConfig
Sourcefn clone(&self) -> FocusTrackerConfig
fn clone(&self) -> FocusTrackerConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FocusTrackerConfig
impl Debug for FocusTrackerConfig