pub struct IgnoreRules { /* private fields */ }Expand description
A set of ignore rules. A focus event is ignored when any rule matches.
Order is preserved for debugging; matching is order-independent.
Implementations
Sourceimpl IgnoreRules
impl IgnoreRules
Sourcepub fn new<I>(rules: I) -> Selfwhere
I: IntoIterator<Item = IgnoreRule>,
pub fn new<I>(rules: I) -> Selfwhere
I: IntoIterator<Item = IgnoreRule>,
Builds a rule set from an iterator of rules.
Sourcepub fn matches(&self, process_name: &str, window_title: Option<&str>) -> bool
pub fn matches(&self, process_name: &str, window_title: Option<&str>) -> bool
Returns true when at least one rule matches.
Sourcepub fn iter(&self) -> impl Iterator<Item = &IgnoreRule>
pub fn iter(&self) -> impl Iterator<Item = &IgnoreRule>
Iterates over the rules in insertion order.